# Tj text - набор утилит для работы с текстом

Установить пакет в локальное окружение со всеми dev и test зависимостями можно командой

```shell
flit install
```

### Публикация пакета в pypi

Пакет публикуется в публичный pypi репозиторий 
[pypi-tj](https://pypi.org/project/tj-text/) на этапе ci по тэгу в мастер.

Для публикации используется общий аккаунт `tinkoffjournal`. 
Спросить про доступы можно у @a.gabdullin.

> **Attention**
> 
> Пока не удалось исправить проблему с коннектом через прокси 
> для публикации пакета в pypi в ci. 
> 
> Поэтому заливать пакет нужно **вручную** командой `flit publish`


### Версионирование

Поднятие версии делаем отдельным коммитом с описанием изменений.